from datetime import timezone
from typing import Iterable, Optional

from acron.job import Job


__all__ = [
    "__version__",
    "run",
    "Job",
]


__version__ = "0.1.6"


async def run(jobs: Iterable[Job], tz: Optional[timezone] = None) -> None:
    """
    Run given jobs with given timezone forever.
    """
    from acron.scheduler import Scheduler

    async with Scheduler(tz=tz) as _scheduler:
        await _scheduler.update_jobs(set(jobs))
        await _scheduler.wait()



from dataclasses import dataclass
from typing import Optional, Callable, Awaitable

__all__ = [
    "Job",
]


@dataclass(frozen=True)
class Job:
    schedule: str
    func: Callable[[], Awaitable[None]]
    name: Optional[str] = None
    enabled: bool = True
